ever_initialized_map

Function ever_initialized_map 

fn ever_initialized_map(
    db: &dyn HirDatabase,
    body: &MirBody<'_>,
) -> ArenaMap<BasicBlockId, ArenaMap<LocalId, bool>>
Returns a map from basic blocks to the set of locals that might be ever initialized before the start of the block. Only StorageDead can remove something from this map, and we ignore Uninit and drop and similar after initialization.